#
# spec file for package python-notebook
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global flavor %{nil}
%if "%{flavor}" == "test"
%define psuffix -test
%bcond_without test
%else
%define psuffix %{nil}
%bcond_with test
BuildArch:      noarch
%endif

%if 0%{?suse_version} > 1500
%bcond_without libalternatives
%else
%bcond_with libalternatives
%endif

Name:           python-notebook%{psuffix}
Version:        7.2.2
Release:        1.1
Summary:        Jupyter Notebook interface
License:        BSD-3-Clause
Group:          Development/Languages/Python
URL:            https://github.com/jupyter/notebook
Source0:        https://files.pythonhosted.org/packages/source/n/notebook/notebook-%{version}.tar.gz
Source100:      python-notebook-rpmlintrc
BuildRequires:  %{python_module base >= 3.7}
BuildRequires:  %{python_module hatch-jupyter-builder >= 0.2}
BuildRequires:  %{python_module hatchling >= 1.11}
BuildRequires:  %{python_module jupyterlab >= 4.2 with %python-jupyterlab < 4.3}
BuildRequires:  %{python_module pip}
BuildRequires:  python-rpm-macros >= 20210929
Requires:       jupyter-notebook = %{version}
Requires:       python-tornado >= 6.2
Requires:       (python-jupyter-server >= 2.4 with python-jupyter-server < 3)
Requires:       (python-jupyterlab >= 4.2 with python-jupyterlab < 4.3)
Requires:       (python-jupyterlab-server >= 2.27.1 with python-jupyterlab-server < 3)
Requires:       (python-notebook-shim >= 0.2 with python-notebook-shim < 0.3)
Provides:       python-jupyter_notebook = %{version}-%{release}
Obsoletes:      python-jupyter_notebook < %{version}-%{release}
%if !%{with test}
BuildRequires:  fdupes
BuildRequires:  hicolor-icon-theme
BuildRequires:  jupyter-notebook-filesystem
BuildRequires:  update-desktop-files
%if %{with libalternatives}
BuildRequires:  alts
Requires:       alts
%else
Requires(post): update-alternatives
Requires(postun): update-alternatives
%endif
%endif
%if %{with test}
BuildRequires:  %{python_module importlib_resources >= 5 if %python-base < 3.10}
BuildRequires:  %{python_module ipykernel}
BuildRequires:  %{python_module jupyter-server-test >= 2.4.0 with %python-jupyter-server-test < 3}
BuildRequires:  %{python_module jupyterlab-server-test >= 2.27.1 with %python-jupyterlab-server-test < 3}
BuildRequires:  %{python_module nbval}
BuildRequires:  %{python_module notebook = %{version}}
BuildRequires:  %{python_module pytest >= 7.0}
BuildRequires:  %{python_module pytest-console-scripts}
BuildRequires:  %{python_module pytest-timeout}
BuildRequires:  %{python_module pytest-tornasync}
BuildRequires:  %{python_module requests}
%endif
%python_subpackages

%description
The Jupyter HTML notebook is a web-based notebook environment for
interactive computing.

This package provides the python interface.

%package     -n jupyter-notebook
Summary:        Jupyter Notebook interface
Group:          Development/Languages/Python
Requires:       python3dist(notebook) = %{version}
Suggests:       python3-notebook = %{version}
Conflicts:      python3-jupyter_notebook < 5.7.8
Provides:       jupyter-notebook-doc = %{version}
Obsoletes:      jupyter-notebook-doc < %{version}

%description -n jupyter-notebook
The Jupyter HTML notebook is a web-based notebook environment for
interactive computing.

This package provides the jupyter components.

%prep
%autosetup -p1 -n notebook-%{version}
# We don't want to run selenium tests
rm -rf notebook/tests/selenium
sed -i 's/"--color=yes", //' pyproject.toml

%build
%if !%{with test}
%pyproject_wheel
%endif

%install
%if !%{with test}
%pyproject_install
rm %{buildroot}%{_jupyter_lab_dir}/schemas/@jupyter-notebook/*/package.json.orig
rm %{buildroot}%{_jupyter_labextensions_dir3}/@jupyter-notebook/lab-extension/schemas/@jupyter-notebook/lab-extension/package.json.orig
%python_expand %fdupes %{buildroot}%{$python_sitelib}
%python_clone -a %{buildroot}%{_bindir}/jupyter-notebook
%python_group_libalternatives jupyter-notebook
%suse_update_desktop_file jupyter-notebook
%endif

%if %{with test}
%check
export LANG=en_US.UTF-8
# test_launch_socket_collision: fails because there are still servers listening
pythonall_donttest="test_launch_socket_collision"
%{python_expand # these tests call the wrong interpreter somewhere deep in the stack
if [ "$python_" != "python3_" -a "%{$python_provides}" != "python3" ]; then
  python_$python_donttest+=" or (test_kernels_api and (test_connection or test_culling))"
fi
}
%pytest -v -k "not (${pythonall_donttest} ${python_$python_donttest})"
%endif

%if !%{with test}
%pre
# If libalternatives is used: Removing old update-alternatives entries.
%python_libalternatives_reset_alternative jupyter-notebook

%post
%python_install_alternative jupyter-notebook

%postun
%python_uninstall_alternative jupyter-notebook

%files %{python_files}
%doc README.md
%license LICENSE
%python_alternative %{_bindir}/jupyter-notebook
%{python_sitelib}/notebook-%{version}.dist-info
%{python_sitelib}/notebook/

%files -n jupyter-notebook
%license LICENSE
%{_datadir}/icons/hicolor/scalable/apps/notebook.svg
%{_datadir}/applications/jupyter-notebook.desktop
%dir %{_jupyter_lab_dir}/schemas
%{_jupyter_lab_dir}/schemas/@jupyter-notebook
%{_jupyter_labextensions_dir3}/@jupyter-notebook
%{_jupyter_config} %{_jupyter_server_confdir}/notebook.json
%endif

%changelog
* Sun Sep 15 2024 Ben Greiner <code@bnavigator.de>
- Update to 7.2.2
  * Upgrade JupyterLab dependencies to v4.2.5 #7447 (@krassowski)
* Fri Jul 12 2024 Ben Greiner <code@bnavigator.de>
- Update to 7.2.1
  * Remove pseudoelement obstructing the cell collapser #7392
    (@krassowski)
- Release 7.2
  * Jupyter Notebook 7.2 is based on JupyterLab 4.2, and includes a
    number of new features, bug fixes, and enhancements for
    extension developers. This release is compatible with
    extensions supporting JupyterLab 4.0. Extension authors are
    recommended to consult the Extension Migration Guide which
    lists deprecations and changes to the public API.
  * Full notebook windowing mode by default
  * Improved Shortcuts Editor
  * Dark high contrast theme
* Fri Mar 29 2024 Ben Greiner <code@bnavigator.de>
- Update to 7.1.2
  * Maintenance and upkeep improvements
* Thu Mar  7 2024 Ben Greiner <code@bnavigator.de>
- Update to 7.1.1
  * Jupyter Notebook 7.1 is based on JupyterLab 4.1, and includes a
    number of new features, bug fixes, and enhancements for
    extension developers. This release is compatible with
    extensions supporting JupyterLab 4.0. Extension authors are
    recommended to consult the Extension Migration Guide which
    lists deprecations and changes to the public API.
  [#]# Bugs fixed
  * Grayout "Edit Notebook Metadata" for other file formats. #7265
    (@itsmevichu)
- Release 7.1.0
  [#]# Enhancements made
  * Create a new notebook with a specific kernel from the new
    dropdown #7255 (@jtpio)
  * Add the plugin manager #7198 (@jtpio)
  * Fix toggle functionality for widgets. #7178 (@haok1402)
  * Bump to JupyterLab 4.1.0a4 bis #7172 (@brichet)
  * Update to JupyterLab 4.1.0a3 #7161 (@jtpio)
  * Added Lumino Plugin Description (#7008) #7127 (@Dilip-Jain)
  * Added Edit Notebook Metadata Option (#6402) #7099 (@Dilip-Jain)
  * Update to JupyterLab 4.1 #7096 (@jtpio)
  * Add the JupyterLab resources plugin #6968 (@jtpio)
  [#]# Bugs fixed
  * Fix spurious kernel selection dialog on notebook creation #7258
    (@jtpio)
  * Workaround for the file browser tracker focus issue #7224
    (@jtpio)
- Skip python39: jupyterlab no longer available (due to ipython)
* Sat Jan 20 2024 Ben Greiner <code@bnavigator.de>
- Update to 7.0.7
  * Update to JupyterLab 4.0.11 #7215 (@krassowski)
    (packaged js files update, CVE-2024-22420 and CVE-2024-22421)
* Thu Dec 28 2023 Ben Greiner <code@bnavigator.de>
- Update to 7.0.6
  * Updated fav-icon Base URL from JupyterLab PageConfig. #7109
    (@jayeshsingh9767)
* Sat Oct 14 2023 Ben Greiner <code@bnavigator.de>
- Update to 7.0.5
  * Update to JupyterLab 4.0.7 #7103 (@jtpio)
  * Maintenance and upkeep improvements: Bump some JS stuff
* Sun Sep 24 2023 Ben Greiner <code@bnavigator.de>
- Update to 7.0.4
  * Update to JupyterLab 4.0.6 #7049 (@jtpio)
  * Fix app_version #7061 (@jtpio)
  * fix trusted status indication #7036 (@adigaboy)
- Release 7.0.3
  * Require importlib_resources for testing on Python < 3.10 #7016 (@bnavigator)
  * Fix Python 3.12 compatibility #6965 (@frenzymadness)
- Drop notebook-issue7014-fixtests.patch
* Sat Aug 19 2023 Ben Greiner <code@bnavigator.de>
- Update to 7.0.2
  * Update to JupyterLab 4.0.4 packages #6998 (@jtpio)
  * Improve about dialog #6996 (@yjrab)
  * Added documentation link in Help menu #6993 (@Mikil03)
- Release 7.0.1
  * Update accessibly compliance section in the docs #6982
    (@andrii-i)
  * Update the browser tab favicon on kernel busy #6980 (@jtpio)
- Release 7.0.0
  [#]# New features
  * https://jupyter-notebook.readthedocs.io/en/latest/notebook_7_features.h
  * Debugger
  * Real Time collaboration
  * Table of Contents
  * Theming and Dark Mode
  * Internationalization
  * Accessibility Improvements
  * Support for many JupyterLab extensions
  * A document-centric user experience
  * Compact View on Mobile Devices
  [#]# Migrating to Notebook 7
  * https://jupyter-notebook.readthedocs.io/en/latest/migrate_to_notebook7.html
  * If you need to maintain compatibility with the Classic Notebook
    for extensions or other customizations that are critical to
    your workflows, you can switch to nbclassic, which will provide
    compatibility with the old notebook interface and support
    during an intermediate transition period to Notebook 7
- Add notebook-issue7014-fixtests.patch gh#jupyter/notebook#7014
* Mon Aug  7 2023 Jiri Srain <jsrain@suse.com>
- Don't require pandoc on ALP
* Sun Apr 23 2023 Ben Greiner <code@bnavigator.de>
- Update to 6.5.4
  * Add show_banner trait to control the banner display #6808
    (@echarles)
* Tue Apr  4 2023 Ben Greiner <code@bnavigator.de>
- Fix debugsources error by having and %%install section in :test
  flavor
* Thu Mar 30 2023 Ben Greiner <code@bnavigator.de>
- Pin to jupyter-client < 8
  * gh#jupyter/notebook#6748
* Sun Mar 19 2023 Ben Greiner <code@bnavigator.de>
- Update to 6.5.3
  * Add a banner and log to information about the migration to
    Notebook 7 plan #6742 (@echarles)
  * Add sys_info to page template for 6.5.x #6668 (@juhasch)
  * Add .mo and .json files for translations #6728 (@frenzymadness)
  * Apply PR #6609 to 6.5.x (Fix rename_file and delete_file to
    handle hidden files properly) #6660 (@yacchin1205)
* Mon Dec 26 2022 Ben Greiner <code@bnavigator.de>
- Update to 6.5.2
  * Ensure custom preload is correctly handled #6580 (@echarles)
  * Fix: jQuery-UI 404 Error by updating dependency path in static
    template #6578 (@RRosio)
  * Depend on nbclassic 0.4.7 #6593 (@echarles)
- Drop upstreamed patch notebook-pr6578+pr6580-404errors.patch
- Drop dependency on jupyter-nbformat, empty subpackage got removed
* Thu Oct 27 2022 Ben Greiner <code@bnavigator.de>
- Add notebook-pr6578+pr6580-404errors.patch
  * fix 404 errors at startup
  * gh#jupyter/notebook#6580 -- custom preload
  * gh#jupyter/notebook#6578 -- jquery from nbclassic
* Wed Oct 26 2022 Ben Greiner <code@bnavigator.de>
- Update to 6.5.1
  * fix: pin temporary to nbclassic 0.4.5 #6570 (@echarles)
- Release 6.5.0
  * Forward port of #6461 - Fix a typo in exception text #6545
    (@krassowski)
  * Normalise os_path #6540 (@krassowski)
* Tue Aug  2 2022 Ben Greiner <code@bnavigator.de>
- Enforce libalternatives grouping for nbclassic alternatives
  gh#jupyter/notebook#6501
* Wed Jun 15 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- update to version 6.4.12:
  * Address security advisory GHSA-v7vq-3x77-87vg
  * CVE-2022-29238
* Mon Jun  6 2022 Ben Greiner <code@bnavigator.de>
- Update runtime requirements, clean up test requirements
* Mon Jun  6 2022 Timothy Brown <stimut@gmail.com>
- update to version 6.4.11:
  * Bugs fixed
    + Update further to ipykernel comm refactoring
  * Maintenance and upkeep improvements
    + Add testpath to the test dependencies
    + Temporary workaround to fix js-tests related to sanitizer js loading by phantomjs
    + Use place-hold.it instead of plaecehold.it to create image placeholders
    + Migrate to python 3.7+
* Thu Feb 17 2022 Arun Persaud <arun@gmx.de>
- update to version 6.4.8:
  * Bugs fixed
    + Fix to remove potential memory leak on Jupyter Notebooks
    ZMQChannelHandler code #6251 (@Vishwajeet0510)
* Sun Jan 23 2022 Arun Persaud <arun@gmx.de>
- specfile:
  * update copyright year
- update to version 6.4.7:
  * Bugs fixed
    + Fix Chinese punctuation #6268 (@LiHua-Official)
    + Add date field to kernel message header #6265 (@kevin-bates)
    + Fix deprecation warning #6253 (@tornaria)
  * Maintenance and upkeep improvements
    + Enforce labels on PRs #6235 (@blink1073)
    + Fix: CI error for python 3.6 & macOS #6215 (@penguinolog)
  * Other merged PRs
    + handle KeyError when get session #6245 (@ccw630)
    + Updated doc for passwd #6209 (@antoinecarme)
* Sat Nov 27 2021 Arun Persaud <arun@gmx.de>
- update to version 6.4.6:
  * Bugs fixed
    + Fix asyncio error when opening notebooks #6221 (@dleen)
    + Change to use a universal Chinese translation on certain words
    [#6218] (@jackexu)
    + Fix Chinese translation typo #6211 (@maliubiao
    + Fix send2trash tests failing on Windows #6127 (@dolfinus)
  * Maintenance and upkeep improvements
    + TST: don't look in user site for serverextensions #6233
    (@bnavigator)
    + Enable terminal tests as pywinpty is ported for python 3.9 #6228
    (@nsait-linaro)
* Fri Nov 12 2021 Ben Greiner <code@bnavigator.de>
- Reenable libalternatives
- Export PYTHONNOUSERSITE when testing for jupyter-core 4.9.1
* Thu Oct 28 2021 Ben Greiner <code@bnavigator.de>
- Revert the usage of libalternatives due to
  gh#openSUSE/libalternatives#11
* Wed Oct 20 2021 Stefan Schubert <schubi@schubi.de>
- Use libalternatives instead of update-alternatives.
* Wed Oct 20 2021 Ben Greiner <code@bnavigator.de>
- Update to version 6.4.5
  * Recover from failure to render mimetype
  * Fix crypto handling
  * Fix jupyter_client warning
  * Fix nbsphinx settings
  * Fully revert the pinning of nbsphinx to 0.8.6
  * Pin nbsphinx to 0.8.6, clean up orphaned resources
  * Fix typo in docstring
- Release 6.4.4
  * Update Manual Release Instructions
  * Use default JupyterLab CSS sanitizer options for Markdown
  * Fix syntax highlight
- Release 6.4.3
  * Add @babel/core dependency
  * Switch webpack to production mode
  * Clean up link checking
- Release 6.4.2
  * Add missing file to manifest
  * Fix issue #3218
  * Fix version of jupyter-packaging in pyproject.toml
  * "#element".tooltip is not a function on home page fixed.
  * Enhancements to the desktop entry
  * Add missing spaces to help messages in config file
- Release 6.4.0
  * Fix Handling of Encoded Paths in Save As Dialog
  * Fix: split_cell doesn't always split cell
  * Correct 'Content-Type' headers
  * Fix skipped tests & remove deprecation warnings
  * [Gateway] Track only this server's kernels
  * Bind the HTTPServer in start #6061
  * Revert "do not apply asyncio patch for tornado >=6.1"
  * Use Jupyter Releaser
  * Add Workflow Permissions for Lock Bot
  * Fixes related to the recent changes in the documentation
  * Add maths checks in CSS reference test
  * Add Issue Lock and Answered Bots
  * Spelling correction
  * Minor typographical and comment changes
  * Fixes related to the recent changes in the documentation
  * Fix readthedocs environment
- Release 6.3.0
  * Add square logo and desktop entry files
  * Modernize Changelog
  * Add missing "import inspect"
  * Add Codecov badge to README
  * Remove configuration for nosetests from setup.cfg
  * Update security.rst
  * Docs-Translations: Updated Hindi and Chinese Readme.md
  * Allow /metrics by default if auth is off
  * Skip terminal tests on Windows 3.9+ (temporary)
  * Update GatewayKernelManager to derive from
    AsyncMappingKernelManager
  * Drop use of deprecated pyzmq.ioloop
  * Drop support for Python 3.5
  * Allow jupyter_server-based contents managers in notebook
  * Russian translation fixes
  * Increase culling test idle timeout
  * Re-enable support for answer_yes flag
  * Replace Travis and Appveyor with Github Actions
  * DOC: Server extension, extra docs on
    configuration/authentication.
- Silence rpmlint2
* Sun Feb 14 2021 Arun Persaud <arun@gmx.de>
- specfile:
  * update copyright year
  * update tornado version requirement
  * removed remove_nose.patch, included upstream
- update to version 6.2.0:
  * Increase minimum tornado version (:ghpull:`5933`)
  * Adjust skip decorators to avoid remaining dependency on nose
    (:ghpull:`5932`)
  * Ensure that cell ids persist after save (:ghpull:`5928`)
  * Add reconnection to Gateway (form nb2kg) (:ghpull:`5924`)
  * Fix some typos (:ghpull:`5917`)
  * Handle TrashPermissionError, now that it exists (:ghpull:`5894`)
- changes from version 6.1.6:
  * do not require nose for testing (:ghpull:`5826`)
  * [docs] Update Chinese and Hindi readme.md (:ghpull:`5823`)
  * Add support for creating terminals via GET (:ghpull:`5813`)
  * Made doc translations in Hindi and Chinese (:ghpull:`5787`)
* Sat Jan  9 2021 Benjamin Greiner <code@bnavigator.de>
- Don't test with pandoc on ix86
* Mon Dec 21 2020 Benjamin Greiner <code@bnavigator.de>
- Update to 6.1.5
  * Fix open redirect vulnerability GHSA-c7vm-f5p4-8fqh
    (CVE to be assigned)
- Changes for 6.1.4
  * Fix broken links to jupyter documentation
  * Add additional entries to troubleshooting section
  * Revert change in page alignment
  * Bug fix: remove double encoding in download files
  * Fix typo for Check in zh_CN
  * Require a file name in the "Save As" dialog
- Changes for 6.1.3
  * Title new buttons with label if action undefined
- Changes for 6.1.2
  * Fix russian message format for delete/duplicate actions
  * Remove unnecessary import of bind_unix_socket
  * Tooltip style scope fix
- Changes for 6.1.1
  * Prevent inclusion of requests_unixsocket on Windows
- Changes for 6.1.0
  Please note that this repository is currently maintained by a
  skeleton crew of maintainers from the Jupyter community. For our
  approach moving forward, please see this notice from the README.
  Thank you.
  * Remove deprecated encoding parameter for Python 3.9
    compatibility.
  * Add support for async kernel management
  * Fix typo in password_required help message
  * Gateway only: Ensure launch and request timeouts are in sync
  * Update Markdown Cells example to HTML5 video tag
  * Integrated LoginWidget into edit to enable users to logout
    from the t…
  * Update message about minimum Tornado version
  * Logged notebook type
  * Added nl language
  * Add UNIX socket support to notebook server.
  * Update CodeMirror dependency
  * Tree added download multiple files
  * Toolbar buttons tooltip: show help instead of label
  * Remove unnecessary import of requests_unixsocket
  * Add ability to cull terminals and track last activity
  * Code refactoring notebook.js
  * Install terminado for docs build
  * Convert notifications JS test to selenium
  * Add cell attachments to markdown example
  * Add Japanese document
  * Migrate Move multiselection test to selenium
  * Use cmdtrl-enter to run a cell
  * Fix broken "Raw cell MIME type" dialog
  * Make a notebook writable after successful save-as
  * Add actual watch script
  * Added --autoreload flag to NotebookApp
  * Enable check_origin on gateway websocket communication
  * Restore detection of missing terminado package
  * Culling: ensure last_activity attr exists before use
  * Added functionality to allow filter kernels by Jupyter
    Enterprise Gat…
  * 'Play' icon for run-cell toolbar button
  * Bump minimum version of jQuery to 3.5.0
  * Remove old JS markdown tests, add a new one in selenium
  * Add support for more RTL languages
  * Make markdown cells stay RTL in edit mode
  * Unforce RTL output display
  * Fixed multicursor backspacing
  * Implemented Split Cell for multicursor
  * Alignment issue [FIXED]
  * MathJax: Support for \gdef
  * Another (Minor) Duplicate Code Reduction
  * Update readme regarding maintenance
  * Document contents chunks
  * Backspace deletes empty line
  * The dropdown submenu at notebook page is not keyboard
    accessible
  * Tooltips visible through keyboard navigation for specified
    buttons
  * Fix for recursive symlink
  * Fix for the terminal shutdown issue
  * Add japanese translation files
  * Workaround for socket permission errors on Cygwin
  * Implement optional markdown header and footer files
  * Remove double link when using custom_display_url
  * Respect cell.is_editable during find-and-replace
  * Fix exception causes all over the codebase (:ghpull:`5556`
  * Improve login shell heuristics
  * Added support for JUPYTER_TOKEN_FILE
  * Kill notebook itself when server cull idle kernel
  * Implement password hashing with bcrypt
  * Fix broken links
  * Russian internationalization support
  * Add a metadata tag to override notebook direction (ltr/rtl)
  * Paste two images from clipboard in markdown cell
  * Add keyboard shortcuts to menu dropdowns
  * Update codemirror to 5.56.0+components1
- refresh remove_nose.patch based on gh#jupyter/notebook#5826
- move the entrypoints to the flavored python package and make them
  alternatives
- tag language files
* Thu Oct 22 2020 Matej Cepl <mcepl@suse.com>
- Add remove_nose.patch to remove dependency on nose
  (gh#jupyter/notebook#4753).
* Tue Jan 28 2020 Todd R <toddrme2178@gmail.com>
- Update to 6.0.3
  * Dependency updates to fix startup issues on Windows platform
  * Add support for nbconvert 6.x
  * Creation of recent tab
- Use multibuild to separate out tests.
  The tests have some heavy dependencies the main package doesn't.
- Drop documentation.
  These are mostly a relic of when the tests needed to be in a
  separate package, and since the docs are no longer versioned
  upstream keeping them synced with the main package is difficult.
* Wed Nov 13 2019 Todd R <toddrme2178@gmail.com>
- jupyter_client renamed to jupyter-client
- jupyter_core renamed to jupyter-core
* Mon Nov 11 2019 Todd R <toddrme2178@gmail.com>
- Update to 6.0.2
  * Update JQuery dependency to version 3.4.1 to fix security vulnerability (CVE-2019-11358)
  * Update CodeMirror to version 5.48.4 to fix Python formatting issues
  * Continue removing obsolete Python 2.x code/dependencies
  * Multiple documentation updates
- Update to 6.0.1
  * Attempt to re-establish websocket connection to Gateway
  * Add missing react-dom js to package data
- Update to 6.0
  * Remove Python 2.x support in favor of Python 3.5 and higher.
  * Multiple accessibility enhancements and bug-fixes.
  * Multiple translation enhancements and bug-fixes.
  * Remove deprecated ANSI CSS styles.
  * Native support to forward requests to Jupyter Gateway(s) (Embedded NB2KG).
  * Use JavaScript to redirect users to notebook homepage.
  * Enhanced SSL/TLS security by using PROTOCOL_TLS which selects the highest ssl/tls
  p  rotocol version available that both the client and server support. When PROTOCOL_TLS
    is not available use PROTOCOL_SSLv23.
  * Add ``?no_track_activity=1`` argument to allow API requests.
    to not be registered as activity (e.g. API calls by external activity monitors).
  * Kernels shutting down due to an idle timeout is no longer considered
    an activity-updating event.
  * Further improve compatibility with tornado 6 with improved
    checks for when websockets are closed.
  * Launch the browser with a local file which redirects to the server address including
    the authentication token. This prevents another logged-in user from stealing the token
    from command line arguments and authenticating to the server.
    The single-use token previously used to mitigate this has been removed.
    Thanks to Dr. Owain Kenway for suggesting the local file approach.
  * Respect nbconvert entrypoints as sources for exporters
  * Update to CodeMirror to 5.37, which includes f-string syntax for Python 3.6.
  * Update jquery-ui to 1.12
  * Execute cells by clicking icon in input prompt.
  * New "Save as" menu option.
  * When serving on a loopback interface, protect against DNS rebinding by
    checking the ``Host`` header from the browser.
    This check can be disabled if necessary by setting
    ``NotebookApp.allow_remote_access``.
  * Add kernel_info_timeout traitlet to enable restarting slow kernels.
  * Add ``custom_display_host`` config option to override displayed URL.
  * Add /metrics endpoint for Prometheus Metrics.
  * Optimize large file uploads.
  * Allow access control headers to be overriden in jupyter_notebook_config.py to support
    greater CORS and proxy configuration flexibility.
  * Add support for terminals on windows.
  * Add a "restart and run all" button to the toolbar.
  * Frontend/extension-config: allow default json files in a .d directory.
  * Allow setting token via jupyter_token env.
  * Cull idle kernels using ``--MappingKernelManager.cull_idle_timeout``.
  * Allow read-only notebooks to be trusted.
  * Convert JS tests to Selenium.
* Tue May 28 2019 Jan Engelhardt <jengelh@inai.de>
- Use noun phrase in summary.
* Fri May 24 2019 Todd R <toddrme2178@gmail.com>
- Add a jupyter-specific language package
* Wed May 22 2019 Todd R <toddrme2178@gmail.com>
- Split directories and macros into separate package.
- Make lang subpackage python version-specific
* Wed May 15 2019 Todd R <toddrme2178@gmail.com>
- Add conflicts to jupyter subpackage to more explicitly handle
  file overlaps with old naming scheme.
* Thu Apr 25 2019 Todd R <toddrme2178@gmail.com>
- Update to 5.7.8
  * Fix regression in restarting kernels in 5.7.5.
    The restart handler would return before restart was completed.
  * Further improve compatibility with tornado 6 with improved
    checks for when websockets are closed.
  * Fix regression in 5.7.6 on Windows where .js files could have the wrong mime-type.
  * Fix Open Redirect vulnerability (CVE-2019-10255)
    where certain malicious URLs could redirect from the Jupyter login page
    to a malicious site after a successful login.
    5.7.7 contained only a partial fix for this issue.
- Rename to to match python package naming guidelines.
- Split jupyter components into own subpackage.
- Add rpm macros.
* Mon Apr  1 2019 Todd R <toddrme2178@gmail.com>
- Fix doc url
* Sat Mar 30 2019 Arun Persaud <arun@gmx.de>
- update to version 5.7.7:
  * Fix regression in restarting kernels in 5.7.5. The restart handler
    would return before restart was completed.
  * Further improve compatibility with tornado 6 with improved checks
    for when websockets are closed.
  * Fix regression in 5.7.6 on Windows where .js files could have the
    wrong mime-type.
  * Fix Open Redirect vulnerability where certain malicious URLs could
    redirect from the Jupyter login page to a malicious site after a
    successful login. A CVE has been requested for this vulnerability.
* Sun Mar 10 2019 Arun Persaud <arun@gmx.de>
- update to version 5.7.6:
  * 5.7.6 contains a security fix for a cross-site inclusion (XSSI)
    vulnerability, where files at a known URL could be included in a
    page from an unauthorized website if the user is logged into a
    Jupyter server. The fix involves setting the
    X-Content-Type-Options: nosniff header, and applying CSRF checks
    previously on all non-GET API requests to GET requests to API
    endpoints and the /files/ endpoint.
    The attacking page is able to access some contents of files when
    using Internet Explorer through script errors, but this has not
    been demonstrated with other browsers. A CVE has been requested
    for this vulnerability.
* Sat Mar  9 2019 Arun Persaud <arun@gmx.de>
- update to version 5.7.5:
  * Fix compatibility with tornado 6 (:ghpull:`4392`, :ghpull:`4449`).
  * Fix opening integer filedescriptor during startup on Python 2
    (:ghpull:`4349`)
  * Fix compatibility with asynchronous KernelManager.restart_kernel
    methods (:ghpull:`4412`)
* Fri Jan 11 2019 rolf@rotkraut.de
- Update requirements: python-jupyter_core >= 4.4.0, python-terminado >= 0.8.1.
* Wed Jan  9 2019 Jan Engelhardt <jengelh@inai.de>
- Fix {name} -> %%{name}
* Fri Jan  4 2019 Todd R <toddrme2178@gmail.com>
- Update to 5.7.4
  * fixes a bug introduced in 5.7.3, in which the ``list_running_servers()``
    function attempts to parse HTML files as JSON, and consequently crashes
  (:ghpull:`4284`).
- Update to 5.7.3
  * Launch the browser with a local file which redirects to the server address
    including the authentication token (:ghpull:`4260`).
    This prevents another logged-in user from stealing the token from command line
    arguments and authenticating to the server.
    The single-use token previously used to mitigate this has been removed.
    Thanks to Dr. Owain Kenway for suggesting the local file approach.
  * Upgrade bootstrap to 3.4, fixing an XSS vulnerability, which has been
    assigned `CVE-2018-14041 <https://nvd.nist.gov/vuln/detail/CVE-2018-14041>`_
    (:ghpull:`4271`).
* Sat Nov 24 2018 Arun Persaud <arun@gmx.de>
- update to version 5.7.2:
  * 5.7.2 contains a security fix preventing malicious directory names
    from being able to execute javascript. CVE request pending.
- changes from version 5.7.1:
  * 5.7.1 contains a security fix preventing nbconvert endpoints from
    executing javascript with access to the server API. CVE request
    pending.
* Fri Sep 28 2018 Todd R <toddrme2178@gmail.com>
- Update to version 5.7.0
  + New features:
  * Update to CodeMirror to 5.37, which includes f-string sytax for Python 3.6 (:ghpull:`3816`)
  * Update jquery-ui to 1.12 (:ghpull:`3836`)
  * Check Host header to more securely protect localhost deployments from DNS rebinding.
    This is a pre-emptive measure, not fixing a known vulnerability (:ghpull:`3766`).
    Use ``.NotebookApp.allow_remote_access`` and ``.NotebookApp.local_hostnames`` to configure
    access.
  * Allow access-control-allow-headers to be overridden (:ghpull:`3886`)
  * Allow configuring max_body_size and max_buffer_size (:ghpull:`3829`)
  * Allow configuring get_secure_cookie keyword-args (:ghpull:`3778`)
  * Respect nbconvert entrypoints as sources for exporters (:ghpull:`3879`)
  * Include translation sources in source distributions (:ghpull:`3925`, :ghpull:`3931`)
  * Various improvements to documentation (:ghpull:`3799`, :ghpull:`3800`,
    :ghpull:`3806`, :ghpull:`3883`, :ghpull:`3908`)
  + Fixing problems:
  * Fix breadcrumb link when running with a base url (:ghpull:`3905`)
  * Fix possible type error when closing activity stream (:ghpull:`3907`)
  * Disable metadata editing for non-editable cells (:ghpull:`3744`)
  * Fix some styling and alignment of prompts caused by regressions in 5.6.0.
  * Enter causing page reload in shortcuts editor (:ghpull:`3871`)
  * Fix uploading to the same file twice (:ghpull:`3712`)
  * Drop -doc subpackage.  Use pre-built upstream docs instead.
* Thu Aug  2 2018 toddrme2178@gmail.com
- Update to version 5.6.0
  + New features:
  * Execute cells by clicking icon in input prompt (:ghpull:`3535`, :ghpull:`3687`)
  * New "Save as" menu option (:ghpull:`3289`)
  * When serving on a loopback interface, protect against DNS rebinding by
    checking the ``Host`` header from the browser (:ghpull:`3714`).
    This check can be disabled if necessary by setting
    ``NotebookApp.allow_remote_access``.
    (Disabled by default while we work out some Mac issues in :ghissue:`3754`).
  * Add kernel_info_timeout traitlet to enable restarting slow kernels (:ghpull:`3665`)
  * Add ``custom_display_host`` config option to override displayed URL (:ghpull:`3668`)
  * Add /metrics endpoint for Prometheus Metrics (:ghpull:`3490`)
  * Update to MathJax 2.7.4 (:ghpull:`3751`)
  * Update to jQuery 3.3 (:ghpull:`3655`)
  * Update marked to 0.4 (:ghpull:`3686`)
  + Fixing problems:
  * Don't duplicate token in displayed URL (:ghpull:`3656`)
  * Clarify displayed URL when listening on all interfaces (:ghpull:`3703`)
  * Don't trash non-empty directories on Windows (:ghpull:`3673`)
  * Include LICENSE file in wheels (:ghpull:`3671`)
- Don't show "0 active kernels" when starting the notebook (:ghpull:`3696`)
  + Testing:
  * Add find replace test (:ghpull:`3630`)
  * Selenium test for deleting all cells (:ghpull:`3601`)
  * Make creating a new notebook more robust (:ghpull:`3726`)
* Tue May 29 2018 toddrme2178@gmail.com
- Update to version 5.5.0
  + New features:
  * The files list now shows file sizes (:ghpull:`3539`)
  * Add a quit button in the dashboard (:ghpull:`3004`)
  * Display hostname in the terminal when running remotely (:ghpull:`3356`, :ghpull:`3593`)
  * Add slides exportation/download to the menu (:ghpull:`3287`)
  * Add any extra installed nbconvert exporters to the "Download as" menu (:ghpull:`3323`)
  * Editor: warning when overwriting a file that is modified on disk (:ghpull:`2783`)
  * Display a warning message if cookies are not enabled (:ghpull:`3511`)
  * Basic ``__version__`` reporting for extensions (:ghpull:`3541`)
  * Add ``NotebookApp.terminals_enabled`` config option (:ghpull:`3478`)
  * Make buffer time between last modified on disk and last modified on last save configurable (:ghpull:`3273`)
  * Allow binding custom shortcuts for 'close and halt' (:ghpull:`3314`)
  * Add description for 'Trusted' notification (:ghpull:`3386`)
  * Add ``settings['activity_sources']`` (:ghpull:`3401`)
  * Add an ``output_updated.OutputArea`` event (:ghpull:`3560`)
  + Fixing problems:
  * Fixes to improve web accessibility (:ghpull:`3507`)
    There is more to do on this! See :ghissue:`1801`.
  * Fixed color contrast issue in tree.less (:ghpull:`3336`)
  * Allow cancelling upload of large files (:ghpull:`3373`)
  * Don't clear login cookie on requests without cookie (:ghpull:`3380`)
  * Don't trash files on different device to home dir on Linux (:ghpull:`3304`)
  * Clear waiting asterisks when restarting kernel (:ghpull:`3494`)
  * Fix output prompt when ``execution_count`` missing (:ghpull:`3236`)
  * Make the 'changed on disk' dialog work when displayed twice (:ghpull:`3589`)
  * Fix going back to root directory with history in notebook list (:ghpull:`3411`)
  * Allow defining keyboard shortcuts for missing actions (:ghpull:`3561`)
  * Prevent default on pageup/pagedown when completer is active (:ghpull:`3500`)
  * Prevent default event handling on new terminal (:ghpull:`3497`)
  * ConfigManager should not write out default values found in the .d directory (:ghpull:`3485`)
  * Fix leak of iopub object in activity monitoring (:ghpull:`3424`)
  * Javascript lint in notebooklist.js (:ghpull:`3409`)
  * Some Javascript syntax fixes (:ghpull:`3294`)
  * Convert native for loop to ``Array.forEach()`` (:ghpull:`3477`)
  * Disable cache when downloading nbconvert output (:ghpull:`3484`)
  * Add missing digestmod arg to HMAC (:ghpull:`3399`)
  * Log OSErrors failing to create less-critical files during startup (:ghpull:`3384`)
  * Use powershell on Windows (:ghpull:`3379`)
  * API spec improvements, API handler improvements (:ghpull:`3368`)
  * Set notebook to dirty state after change to kernel metadata (:ghpull:`3350`)
  * Use CSP header to treat served files as belonging to a separate origin (:ghpull:`3341`)
  * Don't install gettext into builtins (:ghpull:`3330`)
  * Add missing ``import _`` (:ghpull:`3316`, :ghpull:`3326`)
  * Write ``notebook.json`` file atomically (:ghpull:`3305`)
  * Fix clicking with modifiers, page title updates (:ghpull:`3282`)
  * Upgrade jQuery to version 2.2 (:ghpull:`3428`)
  * Upgrade xterm.js to 3.1.0 (:ghpull:`3189`)
  * Upgrade moment.js to 2.19.3 (:ghpull:`3562`)
  * Upgrade CodeMirror to 5.35 (:ghpull:`3372`)
  * "Require" pyzmq>=17 (:ghpull:`3586`)
  + Documentation:
  * Documentation updates and organisation (:ghpull:`3584`)
  * Add section in docs about privacy (:ghpull:`3571`)
  * Add explanation on how to change the type of a cell to Markdown (:ghpull:`3377`)
  * Update docs with confd implementation details (:ghpull:`3520`)
  * Add more information for where ``jupyter_notebook_config.py`` is located (:ghpull:`3346`)
  * Document options to enable nbextensions in specific sections (:ghpull:`3525`)
  * jQuery attribute selector value MUST be surrounded by quotes (:ghpull:`3527`)
  * Do not execute special notebooks with nbsphinx (:ghpull:`3360`)
  * Other minor fixes in :ghpull:`3288`, :ghpull:`3528`, :ghpull:`3293`, :ghpull:`3367`
  + Testing:
  * Testing with Selenium & Sauce labs (:ghpull:`3321`)
  * Selenium utils + markdown rendering tests (:ghpull:`3458`)
  * Convert insert cell tests to Selenium (:ghpull:`3508`)
  * Convert prompt numbers tests to Selenium (:ghpull:`3554`)
  * Convert delete cells tests to Selenium (:ghpull:`3465`)
  * Convert undelete cell tests to Selenium (:ghpull:`3475`)
  * More selenium testing utilities (:ghpull:`3412`)
  * Only check links when build is trigger by Travis Cron job (:ghpull:`3493`)
  * Fix Appveyor build errors (:ghpull:`3430`)
  * Undo patches in teardown before attempting to delete files (:ghpull:`3459`)
  * Get tests running with tornado 5 (:ghpull:`3398`)
  * Unpin ipykernel version on Travis (:ghpull:`3223`)
* Thu Apr 19 2018 toddrme2178@gmail.com
- Update to version 5.4.1
  * A security release to fix CVE-2018-8768.
* Wed Feb 28 2018 toddrme2178@gmail.com
- Package directory needed by jupyterlab
* Thu Feb 15 2018 toddrme2178@gmail.com
- Package additional directories.
* Thu Feb 15 2018 toddrme2178@gmail.com
- update to version 5.4.0
  * Fix creating files and folders after navigating directories in the dashboard
    (:ghpull:`3264`).
  * Enable printing notebooks in colour, removing the CSS that made everything
    black and white (:ghpull:`3212`).
  * Limit the completion options displayed in the notebook to 1000, to avoid
    performance issues with very long lists (:ghpull:`3195`).
  * Accessibility improvements in ``tree.html`` (:ghpull:`3271`).
  * Added alt-text to the kernel logo image in the notebook UI (:ghpull:`3228`).
  * Added a test on Travis CI to flag if symlinks are accidentally introduced
    in the future. This should prevent the issue that necessitated
    :ref:`release-5.3.1` (:ghpull:`3227`).
  * Use lowercase letters for random IDs generated in our Javascript
    (:ghpull:`3264`).
  * Removed duplicate code setting ``TextCell.notebook`` (:ghpull:`3256`).
* Thu Jan 18 2018 toddrme2178@gmail.com
- update to version 5.3.1
  * Add support for terminals on windows (:ghpull:`3087`).
  * Add a "restart and run all" button to the toolbar (:ghpull:`2965`).
  * Send files to os trash mechanism on delete (:ghpull:`1968`).
  * Allow programmatic copy to clipboard (:ghpull:`3088`).
  * Use DOM History API for navigating between directories in the file browser (:ghpull:`3115`).
  * Add translated files to folder(docs-translations) (:ghpull:`3065`).
  * Allow non empty dirs to be deleted (:ghpull:`3108`).
  * Set cookie on base_url (:ghpull:`2959`).
  * Allow token-authenticated requests cross-origin by default (:ghpull:`2920`).
  * Change cull_idle_timeout_minimum to 1 from 300 (:ghpull:`2910`).
  * Config option to shut down server after n seconds with no kernels (:ghpull:`2963`).
  * Display a "close" button on load notebook error (:ghpull:`3176`).
  * Add action to command pallette to run CodeMirror's "indentAuto" on selection (:ghpull:`3175`).
  * Add option to specify extra services (:ghpull:`3158`).
  * Warn_bad_name should not use global name (:ghpull:`3160`).
  * Avoid overflow of hidden form (:ghpull:`3148`).
  * Fix shutdown trans loss (:ghpull:`3147`).
  * Find available kernelspecs more efficiently (:ghpull:`3136`).
  * Don\'t try to translate missing help strings (:ghpull:`3122`).
  * Frontend/extension-config: allow default json files in a .d directory (:ghpull:`3116`).
  * Use `requirejs` vs. `require` (:ghpull:`3097`).
  * Fixes some ui bugs in firefox #3044 (:ghpull:`3058`).
  * Compare non-specific language code when choosing to use arabic numerals (:ghpull:`3055`).
  * Fix save-script deprecation (:ghpull:`3053`).
  * Include moment locales in package_data (:ghpull:`3051`).
  * Fix moment locale loading in bidi support (:ghpull:`3048`).
  * Tornado 5: periodiccallback loop arg will be removed (:ghpull:`3034`).
  * Use `/files` prefix for pdf-like files (:ghpull:`3031`).
  * Add folder for document translation (:ghpull:`3022`).
  * When login-in via token, let a chance for user to set the password (:ghpull:`3008`).
  * Switch to jupyter_core implementation of ensure_dir_exists (:ghpull:`3002`).
  * Send http shutdown request on \'stop\' subcommand (:ghpull:`3000`).
  * Work on loading ui translations  (:ghpull:`2969`).
  * Fix ansi inverse (:ghpull:`2967`).
  * Add send2trash to requirements for building docs (:ghpull:`2964`).
  * I18n readme.md improvement (:ghpull:`2962`).
  * Add \'reason\' field to json error responses (:ghpull:`2958`).
  * Add some padding for stream outputs (:ghpull:`3194`).
  * Always use setuptools in ``setup.py`` (:ghpull:`3206`).
  * Fix clearing cookies on logout when ``base_url`` is configured (:ghpull:`3207`).
* Sun Dec  3 2017 arun@gmx.de
- update to version 5.2.2:
  * set cookie on base_urls (:ghpull:`2959`).
* Sat Nov  4 2017 arun@gmx.de
- update to version 5.2.1:
  * Fix invisible CodeMirror cursor at specific browser zoom levels
    (:ghpull:`2983`).
  * Fix nbconvert handler causing broken export to PDF
    (:ghpull:`2981`).
  * Fix the prompt_area argument of the output area
    constructor. (:ghpull:`2961`).
  * Handle a compound extension in new_untitled (:ghpull:`2949`).
  * Allow disabling offline message buffering (:ghpull:`2916`).
* Thu Oct 26 2017 toddrme2178@gmail.com
- Update to 5.2.0
  * Make all files in the dashboard editable by default and provide
    a whitelist of viewable file extensions (:ghpull:`2911`).
  * Ensure that the root directory is not hidden (:ghpull:`2907`).
  * Fix CodeMirror styling issue (:ghpull:`2880`).
  * Update error handling on ``APIHandlers`` (:ghpull:`2853`).
  * Upgrade xterm.js to 2.9.2 (:ghpull:`2849`).
  * Add Chinese translations (depends on upcoming UI implementation)
    (:ghpull:`2804`).
  * Allow for simpler customization of ``output_prompt`` in
    custom.js (:ghpull:`2774`).
  * Use RFC5987 encoding for filenames (:ghpull:`2767`).
  * Add path to the resources metadata (:ghpull:`2753`).
  * Make ``extraKeys`` consistent between notebook and editor views
    (:ghpull:`2745`).
  * Add RTL (right-to-left) support (:ghpull:`2357`).
* Tue Sep 19 2017 toddrme2178@gmail.com
- Update to 5.1.0
  * Preliminary i18n implementation
  * Expose URL with auth token in notebook UI
  * Fix search background style
  * List running notebooks without requiring ``--allow-root``
  * Allow session of type other than notebook
  * Fix search background style
  * Fix some Markdown styling issues
  * Remove keymaps that conflict with non-English keyboards
  * Add session-specific favicons (notebook, terminal, file)
  * Add /api/shutdown handler
  * Include metadata when copying a cell
  * Stop notebook server from command line
  * Improve "View" and "Edit" file handling in dashboard
  * Provide a promise to replace use of the ``app_initialized.NotebookApp`` event
  * Fix disabled collapse/expand output button
  * Cull idle kernels using ``--MappingKernelManager.cull_idle_timeout``
  * Allow read-only notebooks to be trusted
* Thu Apr 27 2017 toddrme2178@gmail.com
- All python versions can share the empty extension directories
  without conflicting.
* Wed Apr 26 2017 toddrme2178@gmail.com
- Implement single-spec version.
* Thu Mar 30 2017 toddrme2178@gmail.com
- Update to version 5.0.0
  * Files in the dashboard may now be sorted by last modified date or name (:ghpull:`943`):
  * There is a new cell toolbar for adding *cell tags* (:ghpull:`2048`):
  * The default styling for tables in the notebook has been updated (:ghpull:`1776`).
  * You can now edit keyboard shortcuts for *Command Mode* within the UI
  * You can copy and paste cells between notebooks, using :kbd:`Ctrl-C` and
    :kbd:`Ctrl-V` (:kbd:`Cmd-C` and :kbd:`Cmd-V` on Mac).
  * It's easier to configure a password for the notebook with the new
    ``jupyter notebook password`` command (:ghpull:`2007`).
  * The file list can now be ordered by *last modified* or by *name*
    (:ghpull:`943`).
  * Markdown cells now support attachments. Simply drag and drop an image from
    your desktop to a markdown cell to add it. Unlike relative links that you
    enter manually, attachments are embedded in the notebook itself. An
    unreferenced attachment will be automatically scrubbed from the notebook on
    save (:ghpull:`621`).
  * Undoing cell deletion now supports undeleting multiple cells. Cells may not be
    in the same order as before their deletion, depending on the actions you did
    on the meantime, but this should should help reduce the impact of
    accidentally deleting code.
  * The file browser now has *Edit* and *View* buttons.
  * The file browser now supports moving multiple files at once
    (:ghpull:`1088`).
  * The Notebook will refuse to run as root unless the ``--allow-root`` flag is
    given (:ghpull:`1115`).
  * Keyboard shortcuts are now declarative (:ghpull:`1234`).
  * Toggling line numbers can now affect all cells (:ghpull:`1312`).
  * Add more visible *Trusted* and *Untrusted* notifications (:ghpull:`1658`).
  * The favicon (browser shortcut icon) now changes to indicate when the kernel is busy
    (:ghpull:`1837`).
  * Header and toolbar visibility is now persisted in nbconfig and across sessions
    (:ghpull:`1769`).
  * Load server extensions with ConfigManager so that merge happens recursively,
    unlike normal config values, to make it load more consistently with frontend
    extensions(:ghpull:`2108`).
  * The notebook server now supports the `bundler API
    <http://jupyter-notebook.readthedocs.io/en/latest/extending/bundler_extensions.html>`__
    from the `jupyter_cms incubator project
    <https://github.com/jupyter-incubator/contentmanagement>`__ (:ghpull:`1579`).
  * The notebook server now provides information about kernel activity in
    its kernel resource API (:ghpull:`1827`).
- Update to 4.4.0
  * Allow override of output callbacks to redirect output messages. This is used to implement the ipywidgets Output widget, for example.
  * Fix an async bug in message handling by allowing comm message handlers to return a promise which halts message processing until the promise resolves.
- Update to 4.3.2
  * Monkey-patch for CodeMirror that resolves `#2037 <https://github.com/jupyter/notebook/issues/2037>`__ without breaking `#1967 <https://github.com/jupyter/notebook/issues/1967>`__
  * Read-only (``"editable": false``) cells can be executed but cannot be split, merged, or deleted
- Update to 4.3.1
  * CVE-2016-9971. Fix CSRF vulnerability,
    where malicious forms could create untitled files and start kernels
    (no remote execution or modification of existing files)
    for users of certain browsers (Firefox, Internet Explorer / Edge).
    All previous notebook releases are affected.
  - Bug fixes:
  * Fix carriage return handling
  * Make the font size more robust against fickle browsers
  * Ignore resize events that bubbled up and didn't come from window
  * Add Authorization to allowed CORS headers
  * Downgrade CodeMirror to 5.16 while we figure out issues in Safari
  - Other improvements:
  * Better docs for token-based authentication
  * Further highlight token info in log output when autogenerated
- Update to 4.3.0
  - Highlights:
  * API for creating mime-type based renderer extensions using :code:`OutputArea.register_mime_type` and :code:`Notebook.render_cell_output` methods. See `mimerender-cookiecutter <https://github.com/jupyterlab/mimerender-cookiecutter>`__ for reference implementations and cookiecutter.
  * Enable token authentication by default. See :ref:`server_security` for more details.
  * Update security docs to reflect new signature system
  * Switched from term.js to xterm.js
  - Bug fixes:
  * Ensure variable is set if exc_info is falsey
  * Catch and log handler exceptions in :code:`events.trigger`
  * Add debug log for static file paths
  * Don't check origin on token-authenticated requests
  * Remove leftover print statement
  * Fix highlighting of Python code blocks
  * :code:`json_errors` should be outermost decorator on API handlers
  * Fix remove old nbserver info files
  * Fix notebook mime type on download links
  * Fix carriage symbol bahvior
  * Fix terminal styles
  * Update dead links in docs
  * If kernel is broken, start a new session
  * Include cross-origin check when allowing login URL redirects
  - Other improvements:
  * Allow JSON output data with mime type "application/*+json"
  * Allow kernelspecs to have spaces in them for backward compat
  * Allow websocket connections from scripts
  * Allow :code:`None` for post_save_hook
  * Upgrade CodeMirror to 5.21
  * Upgrade xterm to 2.1.0
  * Docs for using comms
  * Set :code:`dirty` flag when output arrives
  * Set :code:`ws-url` data attribute when accessing a notebook terminal
  * Add base aliases for nbextensions
  * Include :code:`@` operator in CodeMirror IPython mode
  * Extend mathjax_url docstring
  * Load nbextension in predictable order
  * Improve the error messages for nbextensions
  * Include cross-origin check when allowing login URL redirects
- Update to 4.2.3
  * Fix regression in 4.2.2 that delayed loading custom.js
    until after ``notebook_loaded`` and ``app_initialized`` events have fired.
  * Fix some outdated docs and links.
- Update to 4.2.2
  * **Security fix**: CVE-2016-6524, where untrusted latex output
    could be added to the page in a way that could execute javascript.
  * Fix missing POST in OPTIONS responses.
  * Fix for downloading non-ascii filenames.
  * Avoid clobbering ssl_options, so that users can specify more detailed SSL configuration.
  * Fix inverted load order in nbconfig, so user config has highest priority.
  * Improved error messages here and there.
- Update to 4.2.1
  * Compatibility fixes for some versions of ipywidgets
  * Fix for ignored CSS on Windows
  * Fix specifying destination when installing nbextensions
- Update to 4.2.0
  * Upgrade MathJax to 2.6 to fix vertical-bar appearing on some equations.
  * Restore ability for notebook directory to be root (4.1 regression)
  * Large outputs are now throttled, reducing the ability of output floods to
    kill the browser.
  * Fix the notebook ignoring cell executions while a kernel is starting by queueing the messages.
  * Fix handling of url prefixes (e.g. JupyterHub) in terminal and edit pages.
  * Support nested SVGs in output.
- Create doc subpackage
* Mon Jan 11 2016 toddrme2178@gmail.com
- Update to 4.1.0
  + Bug fixes:
  - Properly reap zombie subprocesses
  - Fix cross-origin problems
  - Fix double-escaping of the base URL prefix
  - Handle invalid unicode filenames more gracefully
  - Fix ANSI color-processing
  - Send keepalive messages for web terminals
  - Fix bugs in the notebook tour
  + UI changes:
  - Moved the cell toolbar selector into the *View* menu. Added
    a button that triggers a "hint" animation to the main toolbar
    so users can find the new location.
  - Added *Restart & Run All* to the *Kernel* menu. Users can
    also bind it to a keyboard shortcut on action
    ``restart-kernel-and-run-all-cells``.
  - Added multiple-cell selection. Users press ``Shift-Up/Down``
    or ``Shift-K/J`` to extend selection in command mode.
    Various actions such as cut/copy/paste, execute, and cell
    type conversions apply to all selected cells.
  - Added a command palette for executing Jupyter actions by
    name. Users press ``Cmd/Ctrl-Shift-P`` or click the new
    command palette icon on the toolbar.
  - Added a *Find and Replace* dialog to the *Edit* menu.
    Users can also press ``F`` in command mode to show the
    dialog.
  + Other improvements:
  - Custom KernelManager methods can be Tornado coroutines,
    allowing async operations.
  - Make clearing output optional when rewriting input with
    ``set_next_input(replace=True)``.
  - Added support for TLS client authentication via
    ``--NotebookApp.client-ca``.
  - Added tags to ``jupyter/notebook`` releases on DockerHub.
    ``latest`` continues to track the master branch.
* Mon Oct 12 2015 toddrme2178@gmail.com
- update to version 4.0.6:
  * fix installation of mathjax support files
  * fix some double-escape regressions in 4.0.5
  * fix a couple of cases where errors could prevent opening a notebook
- specfile:
  * filename change: tgz->tar.gz
* Mon Oct  5 2015 toddrme2178@gmail.com
- Build documentation
* Wed Sep 23 2015 toddrme2178@gmail.com
- Update to 4.0.5
  * Fix launching the notebook on Windows
  * Fix the path searched for frontend config
* Fri Aug 14 2015 toddrme2178@gmail.com
- Initial version
